@@ -2,7 +2,7 @@
 # vim: ts=4:sw=4:expandtab
 
 ## BleachBit
-## Copyright (C) 2009 Andrew Ziem
+## Copyright (C) 2010 Andrew Ziem
 ## http://bleachbit.sourceforge.net
 ##
 ## This program is free software: you can redistribute it and/or modify
@@ -19,12 +19,30 @@
 ## along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
+
 """
 Launcher
 """
 
-import bleachbit.GUI
-import gtk
 
-gui = bleachbit.GUI.GUI()
-gtk.main()
+
+import os
+import sys
+
+if 'posix' == os.name and os.path.isdir('/usr/share/bleachbit'):
+    # This path contains bleachbit/{C,G}LI.py .  This section is
+    # unnecessary if installing BleachBit in site-packages.
+    sys.path.append('/usr/share/')
+
+
+
+
+if 1 == len(sys.argv):
+    import gtk
+    import bleachbit.GUI
+    gui = bleachbit.GUI.GUI()
+    gtk.main()
+else:
+    import bleachbit.CLI
+    bleachbit.CLI.process_cmd_line()
+
