@@ -355,7 +355,7 @@ class rpmbuild(Cleaner):
         self.add_option('cache', _('Cache'), _('Delete the cache'))
 
     def get_description(self):
-        return _("Delete the files in the rpmbuild build directory")
+        return _("Delete the files in the rpmbuild build folder")
 
     def get_id(self):
         return 'rpmbuild'
@@ -420,7 +420,7 @@ class System(Cleaner):
         if HAVE_GTK:
             self.add_option('clipboard', _('Clipboard'), _('The desktop environment\'s clipboard used for copy and paste operations'))
         self.add_option('free_disk_space', _('Free disk space'), _('Overwrite free disk space to hide deleted files'))
-        self.set_warning('free_disk_space', _('This option is slow.'))
+        self.set_warning('free_disk_space', _('This option is very slow.'))
         self.add_option('tmp', _('Temporary files'), _('Delete the temporary files'))
 
     def get_description(self):
@@ -583,12 +583,16 @@ class System(Cleaner):
             # GNOME 2.26 (as seen on Ubuntu 9.04) will retain the list
             # in memory if it is simply deleted, so it must be shredded
             # (or at least truncated).
+            #
+            # GNOME 2.28.1 (Ubuntu 9.10) and 2.30 (10.04) do not re-read
+            # the file after truncation, but do re-read it after
+            # shreading.
+            #
+            # https://bugzilla.gnome.org/show_bug.cgi?id=591404
             pathname = os.path.expanduser("~/.recently-used.xbel")
             if os.path.lexists(pathname):
-                if options.get('shred'):
-                    yield Command.Shred(pathname)
-                else:
-                    yield Command.Truncate(pathname)
+                yield Command.Shred(pathname)
+                gtk.RecentManager().purge_items()
 
 
         # overwrite free space
