@@ -1,7 +1,7 @@
 # vim: ts=4:sw=4:expandtab
 
 ## BleachBit
-## Copyright (C) 2009 Andrew Ziem
+## Copyright (C) 2010 Andrew Ziem
 ## http://bleachbit.sourceforge.net
 ##
 ## This program is free software: you can redistribute it and/or modify
@@ -17,19 +17,23 @@
 ## You should have received a copy of the GNU General Public License
 ## along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+
+
 """
 Create cleaners from CleanerML (markup language)
 """
 
+
+
 import os
 import sys
 import traceback
 import xml.dom.minidom
-import CleanerBackend
+import Cleaner
 import Common
 
-from gettext import gettext as _
-from Action import ActionContainer, ActionProvider
+from Action import ActionProvider
+from Common import _
 from General import boolstr_to_bool, getText
 from FileUtilities import listdir
 
@@ -45,14 +49,14 @@ class CleanerML:
         """
 
         self.action = None
-        self.cleaner = CleanerBackend.Cleaner()
+        self.cleaner = Cleaner.Cleaner()
         self.option_id = None
         self.option_name = None
         self.option_description = None
         self.option_warning = None
         self.xlate_cb = xlate_cb
         if None == self.xlate_cb:
-            self.xlate_cb = lambda x: None # do nothing
+            self.xlate_cb = lambda x, y = None: None # do nothing
 
         dom = xml.dom.minidom.parse(pathname)
 
@@ -66,8 +70,10 @@ class CleanerML:
 
     def os_match(self, os_str):
         """Return boolean whether operating system matches"""
-        if len(os_str) == 0:
+        # If blank or if in .pot-creation-mode, return true.
+        if len(os_str) == 0 or None != self.xlate_cb:
             return True
+        # Otherwise, check platform.
         if os_str == 'linux' and sys.platform == 'linux2':
             return True
         if os_str == 'windows' and sys.platform == 'win32':
@@ -84,7 +90,12 @@ class CleanerML:
         description = cleaner.getElementsByTagName('description')
         if description and description[0].parentNode == cleaner:
             self.handle_cleaner_description(description[0])
-        self.handle_cleaner_options(cleaner.getElementsByTagName('option'))
+        for option in cleaner.getElementsByTagName('option'):
+            try:
+                self.handle_cleaner_option(option)
+            except:
+                print str(sys.exc_info()[1])
+                print option.toxml()
         self.handle_cleaner_running(cleaner.getElementsByTagName('running'))
 
 
@@ -111,37 +122,34 @@ class CleanerML:
             self.cleaner.add_running(detection_type, value)
 
 
-    def handle_cleaner_options(self, options):
-        """<option> elements"""
-        for option in options:
+    def handle_cleaner_option(self, option):
+        """<option> element"""
+        self.option_id = option.getAttribute('id')
+        self.option_description = None
+        self.option_name = None
 
-            self.action = ActionContainer()
-            self.option_id = option.getAttribute('id')
-            self.option_description = None
-            self.option_name = None
+        self.handle_cleaner_option_label(option.getElementsByTagName('label')[0])
+        description = option.getElementsByTagName('description')
+        self.handle_cleaner_option_description(description[0])
+        warning = option.getElementsByTagName('warning')
+        if warning:
+            self.handle_cleaner_option_warning(warning[0])
+            if self.option_warning:
+                self.cleaner.set_warning(self.option_id, self.option_warning)
 
-            self.handle_cleaner_option_label(option.getElementsByTagName('label')[0])
-            description = option.getElementsByTagName('description')
-            self.handle_cleaner_option_description(description[0])
-            warning = option.getElementsByTagName('warning')
-            if warning:
-                self.handle_cleaner_option_warning(warning[0])
-                if self.option_warning:
-                    self.cleaner.set_warning(self.option_id, self.option_warning)
+        for action in option.getElementsByTagName('action'):
+            self.handle_cleaner_option_action(action)
 
-            for action in option.getElementsByTagName('action'):
-                self.handle_cleaner_option_action(action)
-
-            self.cleaner.add_option(self.option_id, self.option_name, self.option_description)
-            self.cleaner.add_action(self.option_id, self.action)
+        self.cleaner.add_option(self.option_id, self.option_name, self.option_description)
 
 
     def handle_cleaner_option_label(self, label):
         """<label> element under <option>"""
         self.option_name = _(getText(label.childNodes))
         translate = label.getAttribute('translate')
+        translators = label.getAttribute('translators')
         if not translate or boolstr_to_bool(translate):
-            self.xlate_cb(self.option_name)
+            self.xlate_cb(self.option_name, translators)
 
 
     def handle_cleaner_option_description(self, description):
@@ -156,17 +164,19 @@ class CleanerML:
 
     def handle_cleaner_option_action(self, action_node):
         """<action> element under <option>"""
-        atype = action_node.getAttribute('type')
+        command = action_node.getAttribute('command')
         provider = None
         for actionplugin in ActionProvider.plugins:
-            if actionplugin.action_key == atype:
+            if actionplugin.action_key == command:
                 provider = actionplugin(action_node)
-        self.action.add_action_provider(provider)
+        if None == provider:
+            raise RuntimeError("Invalid command '%s'" % command)
+        self.cleaner.add_action(self.option_id, provider)
 
 
 def list_cleanerml_files(local_only = False):
     """List CleanerML files"""
-    cleanerdirs = ( 'cleaners', \
+    cleanerdirs = ( Common.local_cleaners_dir, \
         Common.personal_cleaners_dir )
     if not local_only:
         cleanerdirs += ( Common.system_cleaners_dir, )
@@ -192,18 +202,22 @@ def load_cleaners():
         else:
             cleaner = xmlcleaner.get_cleaner()
             if cleaner.is_usable():
-                CleanerBackend.backends[cleaner.id] = cleaner
+                Cleaner.backends[cleaner.id] = cleaner
             else:
                 print "debug: '%s' is not usable" % pathname
 
 
-def pot_fragment(msgid, pathname):
+def pot_fragment(msgid, pathname, translators = None):
     """Create a string fragment for generating .pot files"""
-    ret = '''#: %s
+    if translators:
+        translators = "#. %s\n" % translators
+    else:
+        translators = ""
+    ret = '''%s#: %s
 msgid "%s"
 msgstr ""
 
-''' % (pathname, msgid)
+''' % (translators, pathname, msgid)
     return ret
 
 
@@ -218,73 +232,20 @@ def create_pot():
         strings = []
         try:
             CleanerML(pathname, \
-                lambda newstr: strings.append(newstr))
+                lambda newstr, translators = None: \
+                strings.append([ newstr, translators ] ))
         except:
             print "error reading '%s'" % pathname
             traceback.print_exc()
         else:
-            for string in sorted(set(strings)):
-                f.write(pot_fragment(string, pathname))
+            for (string, translators) in strings:
+                f.write(pot_fragment(string, pathname, translators))
 
     f.close()
 
 
-import unittest
-
-class TestCleanerML(unittest.TestCase):
-    """Test cases for CleanerML"""
-
-    def test_CleanerML(self):
-        """Unit test for class CleanerML"""
-        xmlcleaner = CleanerML("../doc/example_cleaner.xml")
-
-        self.assert_(isinstance(xmlcleaner, CleanerML))
-        self.assert_(isinstance(xmlcleaner.cleaner, CleanerBackend.Cleaner))
-
-        for (option_id, __name, __value) in xmlcleaner.cleaner.get_options():
-            # enable all options
-            xmlcleaner.cleaner.set_option(option_id, True)
-
-        for pathname in xmlcleaner.cleaner.list_files():
-            self.assert_(os.path.exists(pathname))
-
-
-
-    def test_boolstr_to_bool(self):
-        """Unit test for boolstr_to_bool()"""
-        tests = [ ('True', True), \
-            ('False', False) ]
-
-        for (arg, output) in tests:
-            self.assertEqual(boolstr_to_bool(arg), output)
-            self.assertEqual(boolstr_to_bool(arg.lower()), output)
-            self.assertEqual(boolstr_to_bool(arg.upper()), output)
-
-
-    def test_create_pot(self):
-        """Unit test for create_pot()"""
-        create_pot()
-
-
-    def test_list_cleanerml_files(self):
-        """Unit test for list_cleanerml_files()"""
-        for pathname in list_cleanerml_files():
-            self.assert_(os.path.exists(pathname))
-
-
-    def test_load_cleaners(self):
-        """Unit test for load_cleaners()"""
-        load_cleaners()
-
-
-    def test_pot_fragment(self):
-        """Unit test for pot_fragment()"""
-        self.assert_(type(pot_fragment("Foo", 'bar.xml')) is str)
-
 
 if __name__ == '__main__':
     if 2 == len(sys.argv) and 'pot' == sys.argv[1]:
         create_pot()
-    else:
-        unittest.main()
 
