@@ -37,6 +37,18 @@ else:
     from General import WindowsError
 
 
+def whitelist(path):
+    """Return information that this file was whitelisted"""
+    ret = { \
+        # TRANSLATORS: This is the label in the log indicating was
+        # skipped because it matches the whitelist
+        'label' : _('Skip'),
+        'n_deleted' : 0,
+        'n_special' : 0,
+        'path' : path,
+        'size' : 0 }
+    return ret
+
 
 class Delete:
     """Delete a single file or directory.  Obey the user
@@ -51,6 +63,9 @@ class Delete:
 
     def execute(self, really_delete):
         """Make changes and return results"""
+        if FileUtilities.whitelisted(self.path):
+            yield whitelist(self.path)
+            return
         ret = { \
             # TRANSLATORS: This is the label in the log indicating will be
             # deleted (for previews) or was actually deleted
@@ -65,7 +80,7 @@ class Delete:
             except WindowsError, e:
                 # WindowsError: [Error 32] The process cannot access the file because it is being
                 # used by another process: u'C:\\Documents and Settings\\username\\Cookies\\index.dat'
-                if 32 != e.winerror:
+                if 32 != e.winerror and 5 != e.winerror:
                     raise
                 try:
                     Windows.delete_locked_file(self.path)
@@ -94,6 +109,11 @@ class Function:
             raise AssertionError('Expected MethodType but got %s' % type(func))
 
     def execute(self, really_delete):
+
+        if None != self.path and FileUtilities.whitelisted(self.path):
+            yield whitelist(self.path)
+            return
+
         ret = { \
             'label' : self.label,
             'n_deleted' : 0,
@@ -136,8 +156,8 @@ class Shred(Delete):
 
     def __init__(self, path):
         """Create an instance to shred 'path'"""
-        self.shred = True
         Delete.__init__(self, path)
+        self.shred = True
 
 
 
@@ -147,6 +167,11 @@ class Truncate(Delete):
 
     def execute(self, really_delete):
         """Make changes and return results"""
+
+        if FileUtilities.whitelisted(self.path):
+            yield whitelist(self.path)
+            return
+
         ret = { \
             # TRANSLATORS: The file will be truncated to 0 bytes in length
             'label' : _('Truncate'),
