@@ -1,4 +1,5 @@
 # vim: ts=4:sw=4:expandtab
+# -*- coding: UTF-8 -*-
 
 ## BleachBit
 ## Copyright (C) 2010 Andrew Ziem
@@ -29,7 +30,7 @@ import sys
 import traceback
 
 
-APP_VERSION = "0.7.3"
+APP_VERSION = "0.8.0"
 APP_NAME = "BleachBit"
 APP_URL = "http://bleachbit.sourceforge.net"
 
@@ -70,12 +71,14 @@ if None == license_filename:
     print 'warning: cannot find GPLv3 license text file'
 
 # configuration
+portable_mode = False
 options_dir = None
 if 'posix' == os.name:
     options_dir = os.path.expanduser("~/.config/bleachbit")
 elif 'nt' == os.name:
     if os.path.exists(os.path.join(bleachbit_exe_path, 'bleachbit.ini')):
         # portable mode
+        portable_mode = True
         options_dir = bleachbit_exe_path
     else:
         # installed mode
@@ -161,6 +164,44 @@ except:
         """Dummy replacement for gettext"""
         return msg
 
+
+###
+### pgettext
+###
+
+# Code released in the Public Domain. You can do whatever you want with this package.
+# Originally written by Pierre Métras <pierre@alterna.tv> for the OLPC XO laptop.
+#
+# Original source: http://dev.laptop.org/git/activities/clock/plain/pgettext.py
+
+
+# pgettext(msgctxt, msgid) from gettext is not supported in Python implementation < v2.6.
+# http://bugs.python.org/issue2504
+# Meanwhile we get official support, we have to simulate it.
+# See http://www.gnu.org/software/gettext/manual/gettext.html#Ambiguities for
+# more information about pgettext.
+
+# The separator between message context and message id.This value is the same as
+# the one used in gettext.h, so PO files should be still valid when Python gettext
+# module will include pgettext() function.
+GETTEXT_CONTEXT_GLUE = "\004"
+
+def pgettext(msgctxt, msgid):
+    """A custom implementation of GNU pgettext().
+    """
+    if msgctxt is not None and msgctxt is not "":
+        translation = _(msgctxt + GETTEXT_CONTEXT_GLUE + msgid)
+        if translation.startswith(msgctxt + GETTEXT_CONTEXT_GLUE):
+            return msgid
+        else:
+            return translation
+    else:
+        return _(msgid)
+
+# Map our pgettext() custom function to _p()
+_p = lambda msgctxt, msgid: pgettext(msgctxt, msgid)
+
+
 ###
 ### URLs
 ###
