@@ -34,9 +34,9 @@ import gtk
 import gobject
 warnings.simplefilter('default')
 
-from Common import _, APP_NAME, APP_VERSION, APP_URL, appicon_path, \
-    help_contents_url, license_filename, online_update_notification_enabled, \
-    release_notes_url
+from Common import _, _p, APP_NAME, APP_VERSION, APP_URL, appicon_path, \
+    help_contents_url, license_filename, options_file, options_dir, \
+    online_update_notification_enabled, release_notes_url, portable_mode
 from Cleaner import backends
 from GuiPreferences import PreferencesDialog
 from Options import options
@@ -225,6 +225,7 @@ class GUI:
     <menubar name="MenuBar">
         <menu action="File">
             <menuitem action="ShredFiles"/>
+            <menuitem action="ShredQuit"/>
             <menuitem action="Quit"/>
         </menu>
         <menu action="Edit">
@@ -407,7 +408,7 @@ class GUI:
         dialog.set_version(APP_VERSION)
         dialog.set_website(APP_URL)
         dialog.set_transient_for(self.window)
-        if os.path.exists(appicon_path):
+        if appicon_path and os.path.exists(appicon_path):
             icon = gtk.gdk.pixbuf_new_from_file(appicon_path)
             dialog.set_logo(icon)
         dialog.run()
@@ -493,6 +494,35 @@ class GUI:
         del backends['_gui']
 
 
+    def cb_shred_quit(self, action):
+        """Shred settings (for privacy reasons) and quit"""
+        try:
+            FileUtilities.delete(options_file, shred = True)
+            if portable_mode:
+                open(options_file, 'w').write('[Portable]\n')
+            fn = os.path.join(options_dir, "deepscan.sqlite3")
+            if os.path.exists(fn):
+                FileUtilities.delete(fn, shred = True)
+        except:
+            print traceback.print_exc()
+            err = str(sys.exc_info()[1])
+            self.append_text(err, 'error')
+            return
+
+        if not portable_mode:
+            try:
+                os.rmdir(options_dir)
+            except:
+                print traceback.print_exc()
+                err = str(sys.exc_info()[1])
+                self.append_text(err, 'error')
+                while gtk.events_pending():
+                    gtk.main_iteration()
+                time.sleep(3)
+
+        gtk.main_quit()
+
+
     def update_progress_bar(self, status):
         """Callback to update the progress bar with number or text"""
         if type(status) is float:
@@ -528,6 +558,7 @@ class GUI:
         # Create actions
         entries = (
                     ('ShredFiles', gtk.STOCK_DELETE, _('_Shred Files'), None, None, self.cb_shred_file),
+                    ('ShredQuit', None, _('S_hred Settings and Quit'), None, None, self.cb_shred_quit),
                     ('Quit', gtk.STOCK_QUIT, _('_Quit'), None, None, lambda *dummy: gtk.main_quit()),
                     ('File', None, _('_File')),
                     ('Preferences', gtk.STOCK_PREFERENCES, _("Preferences"), None, None, self.cb_preferences_dialog),
@@ -555,27 +586,26 @@ class GUI:
         """Create the toolbar"""
         toolbar = gtk.Toolbar()
 
-        # create tooltips
-        tooltips = gtk.Tooltips()
-        tooltips.enable()
 
-       # create the preview button
+        # create the preview button
         preview_icon = gtk.Image()
         preview_icon.set_from_stock(gtk.STOCK_FIND, gtk.ICON_SIZE_LARGE_TOOLBAR)
-        preview_button = gtk.ToolButton(icon_widget = preview_icon, label = _("Preview"))
+        # TRANSLATORS: This is the preview button on the main window.  It previews changes.
+        preview_button = gtk.ToolButton(icon_widget = preview_icon, label = _p('button', "Preview"))
         preview_button.connect("clicked", lambda *dummy: self.preview_or_run_operations(False))
         toolbar.insert(preview_button, -1)
-        preview_button.set_tooltip(tooltips, _("Preview files in the selected operations (without deleting any files)"))
+        preview_button.set_tooltip_text(_("Preview files in the selected operations (without deleting any files)"))
         preview_button.set_is_important(True)
 
         # create the delete button
         icon = gtk.Image()
         icon.set_from_stock(gtk.STOCK_DELETE, gtk.ICON_SIZE_LARGE_TOOLBAR)
-        # TRANSLATORS: This is the delete button on the main window
-        run_button = gtk.ToolButton(icon_widget = icon, label = _("Delete"))
+        # TRANSLATORS: This is the delete button on the main window.
+        # It makes permanent changes: usually deleting files, sometimes altering them.
+        run_button = gtk.ToolButton(icon_widget = icon, label = _p("button", "Delete"))
         run_button.connect("clicked", self.run_operations)
         toolbar.insert(run_button, -1)
-        run_button.set_tooltip(tooltips, _("Delete files in the selected operations"))
+        run_button.set_tooltip_text(_("Delete files in the selected operations"))
         run_button.set_is_important(True)
 
         return toolbar
@@ -656,7 +686,7 @@ class GUI:
         """Create a button to launch browser to initiate software update"""
         icon = gtk.Image()
         icon.set_from_stock(gtk.STOCK_NETWORK, gtk.ICON_SIZE_LARGE_TOOLBAR)
-        update_button = gtk.ToolButton(icon_widget = icon, label = _("Update BleachBit"))
+        update_button = gtk.ToolButton(icon_widget = icon, label = _p('button', 'Update BleachBit'))
         update_button.show_all()
         update_button.connect("clicked", lambda toolbutton, url: open_url(url), url)
         update_button.set_is_important(True)
@@ -685,7 +715,7 @@ class GUI:
             if update.is_update_available():
                 gobject.idle_add(self.enable_online_update, update.get_update_info_url())
         except:
-            self.append_text(_("Error when checking for updates: ") + str(sys.exc_info()[1]))
+            self.append_text(_("Error when checking for updates: ") + str(sys.exc_info()[1]), 'error')
 
 
     def __init__(self):
@@ -704,6 +734,16 @@ class GUI:
             options.set('first_start', False)
         if online_update_notification_enabled and options.get("check_online_updates"):
             self.check_online_updates()
+        if 'nt' == os.name:
+            # BitDefender false positive.  BitDefender didn't mark BleachBit as infected or show
+            # anything in its log, but sqlite would fail to import unless BitDefender was in "game mode."
+            # http://bleachbit.sourceforge.net/forum/074-fails-errors
+            try:
+                import sqlite3
+            except ImportError, e:
+                print e
+                print dir(e)
+                self.append_text(_("Error loading the SQLite module: the antivirus software may be blocking it."), 'error')
 
 
 
