@@ -31,7 +31,7 @@ import os
 import sys
 import traceback
 
-from Common import _
+from Common import _, _p
 from Options import options
 import Common
 import GuiBasic
@@ -55,14 +55,12 @@ class PreferencesDialog:
             flags = gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT)
         self.dialog.set_default_size(300, 200)
 
-        self.tooltips = gtk.Tooltips()
-        self.tooltips.enable()
-
         notebook = gtk.Notebook()
         notebook.append_page(self.__general_page(), gtk.Label(_("General")))
         notebook.append_page(self.__drives_page(), gtk.Label(_("Drives")))
         if 'posix' == os.name:
             notebook.append_page(self.__languages_page(), gtk.Label(_("Languages")))
+        notebook.append_page(self.__whitelist_page(), gtk.Label(_("Whitelist")))
 
         self.dialog.vbox.pack_start(notebook, True)
         self.dialog.add_button(gtk.STOCK_CLOSE, gtk.RESPONSE_CLOSE)
@@ -107,7 +105,7 @@ class PreferencesDialog:
             cb_updates = gtk.CheckButton(_("Check periodically for software updates via the Internet"))
             cb_updates.set_active(options.get('check_online_updates'))
             cb_updates.connect('toggled', self.__toggle_callback, 'check_online_updates')
-            self.tooltips.set_tip(cb_updates, _("If an update is found, you will be given the option to view information about it.  Then, you may manually download and install the update."))
+            cb_updates.set_tooltip_text(_("If an update is found, you will be given the option to view information about it.  Then, you may manually download and install the update."))
             vbox.pack_start(cb_updates, False)
 
         # TRANSLATORS: This means to hide cleaners which would do
@@ -125,7 +123,7 @@ class PreferencesDialog:
         cb_shred = gtk.CheckButton(_("Overwrite files to hide contents"))
         cb_shred.set_active(options.get('shred'))
         cb_shred.connect('toggled', self.__toggle_callback, 'shred')
-        self.tooltips.set_tip(cb_shred, _("Overwriting is ineffective on some file systems and with certain BleachBit operations.  Overwriting is significantly slower."))
+        cb_shred.set_tooltip_text(_("Overwriting is ineffective on some file systems and with certain BleachBit operations.  Overwriting is significantly slower."))
         vbox.pack_start(cb_shred, False)
 
         cb_start = gtk.CheckButton(_("Start BleachBit with computer"))
@@ -151,7 +149,10 @@ class PreferencesDialog:
             """Callback for removing a drive"""
             treeselection = treeview.get_selection()
             (model, _iter) = treeselection.get_selected()
-            pathname = model[0][0]
+            if None == _iter:
+                # nothing selected
+                return
+            pathname = model[_iter][0]
             liststore.remove(_iter)
             pathnames.remove(pathname)
             options.set_list('shred_drives', pathnames)
@@ -159,7 +160,7 @@ class PreferencesDialog:
 
         vbox = gtk.VBox()
 
-        notice = gtk.Label(_("Choose a writable directory for each drive for which to overwrite free space."))
+        notice = gtk.Label(_("Choose a writable folder for each drive for which to overwrite free space."))
         notice.set_line_wrap(True)
         vbox.pack_start(notice, False)
 
@@ -179,9 +180,11 @@ class PreferencesDialog:
 
         vbox.pack_start(treeview)
 
-        button_add = gtk.Button(_("Add"))
+        # TRANSLATORS: In the preferences dialog, this button adds a path to the list of paths
+        button_add = gtk.Button(_p('button', 'Add'))
         button_add.connect("clicked", add_drive_cb)
-        button_remove = gtk.Button(_("Remove"))
+        # TRANSLATORS: In the preferences dialog, this button removes a path from the list of paths
+        button_remove = gtk.Button(_p('button', 'Remove'))
         button_remove.connect("clicked", remove_drive_cb)
 
         button_box = gtk.HButtonBox()
@@ -245,6 +248,116 @@ class PreferencesDialog:
         return vbox
 
 
+    def __whitelist_page(self):
+        """Return a widget containing the whitelist page"""
+
+        def add_whitelist_file_cb(button):
+            """Callback for adding a file"""
+            title = _("Choose a file")
+            pathname = GuiBasic.browse_file(self.parent, title)
+            if pathname:
+                for this_pathname in pathnames:
+                    if pathname == this_pathname[1]:
+                        print "warning: '%s' already exists in whitelist" % pathname
+                        return
+                liststore.append( [ _('File'), pathname ] )
+                pathnames.append( [ 'file', pathname ] )
+                options.set_whitelist_paths(pathnames)
+
+
+        def add_whitelist_folder_cb(button):
+            """Callback for adding a folder"""
+            title = _("Choose a folder")
+            pathname = GuiBasic.browse_folder(self.parent, title)
+            if pathname:
+                for this_pathname in pathnames:
+                    if pathname == this_pathname[1]:
+                        print "warning: '%s' already exists in whitelist" % pathname
+                        return
+                liststore.append( [ _('Folder'), pathname ] )
+                pathnames.append( [ 'folder', pathname ] )
+                options.set_whitelist_paths(pathnames)
+
+
+        def remove_whitelist_path_cb(button):
+            """Callback for removing a path"""
+            treeselection = treeview.get_selection()
+            (model, _iter) = treeselection.get_selected()
+            if None == _iter:
+                # nothing selected
+                return
+            pathname = model[_iter][1]
+            liststore.remove(_iter)
+            for this_pathname in pathnames:
+                if this_pathname[1] == pathname:
+                    pathnames.remove(this_pathname)
+                    options.set_whitelist_paths(pathnames)
+
+
+        vbox = gtk.VBox()
+
+        # load data
+        pathnames = options.get_whitelist_paths()
+        liststore = gtk.ListStore(str, str)
+        for paths in pathnames:
+            type_code = paths[0]
+            type_str = None
+            if type_code == 'file':
+                type_str = _('File')
+            elif type_code == 'folder':
+                type_str = _('Folder')
+            else:
+                raise RuntimeError("Invalid type code: '%s'" % type_code)
+            path = paths[1]
+            liststore.append( [ type_str, path ] )
+
+        # TRANSLATORS: "Paths" is used generically to refer to both files and folders
+        notice = gtk.Label(_("Theses paths will not be deleted or modified."))
+        vbox.pack_start(notice)
+
+        # create treeview
+        treeview = gtk.TreeView(liststore)
+
+        # create column views
+        self.renderer0 = gtk.CellRendererText()
+        self.column0 = gtk.TreeViewColumn(_("Type"), self.renderer0, text=0)
+        treeview.append_column(self.column0)
+
+        self.renderer1 = gtk.CellRendererText()
+        # TRANSLATORS: In the tree view "Path" is used generically to refer to a
+        # file, a folder, or a pattern describing either
+        self.column1 = gtk.TreeViewColumn(_("Path"), self.renderer1, text=1)
+        treeview.append_column(self.column1)
+        treeview.set_search_column(1)
+
+        # finish tree view
+        swindow = gtk.ScrolledWindow()
+        swindow.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
+        swindow.set_size_request(300, 200)
+        swindow.add(treeview)
+        vbox.pack_start(swindow, False)
+
+        # buttons that modify the list
+        button_add_file = gtk.Button(_p('button', 'Add file'))
+        button_add_file.connect("clicked", add_whitelist_file_cb)
+
+        button_add_folder = gtk.Button(_p('button', 'Add folder'))
+        button_add_folder.connect("clicked", add_whitelist_folder_cb)
+
+        button_remove = gtk.Button(_p('button', 'Remove'))
+        button_remove.connect("clicked", remove_whitelist_path_cb)
+
+        button_box = gtk.HButtonBox()
+        button_box.set_layout(gtk.BUTTONBOX_START)
+        button_box.pack_start(button_add_file)
+        button_box.pack_start(button_add_folder)
+        button_box.pack_start(button_remove)
+        vbox.pack_start(button_box, False)
+
+        # return page
+        return vbox
+
+
     def run(self):
         """Run the dialog"""
         self.dialog.show_all()
