@@ -49,7 +49,14 @@ class Options:
             General.makedirs(Common.options_dir)
         mkfile = not os.path.exists(Common.options_file)
         _file = open(Common.options_file, 'wb')
-        self.config.write(_file)
+        try:
+            self.config.write(_file)
+        except IOError, e:
+            print e
+            if 28 == e.errno:
+                print "Error: disk is full writing configuration '%s'" % Common.options_file
+            else:
+                raise
         if mkfile and General.sudo_mode():
             General.chownself(Common.options_file)
 
@@ -93,6 +100,24 @@ class Options:
             values.append(self.config.get(section, option))
         return values
 
+    def get_whitelist_paths(self):
+        """Return the whitelist of paths"""
+        section = "whitelist/paths"
+        if not self.config.has_section(section):
+            return []
+        options = []
+        for option in sorted(self.config.options(section)):
+            pos = option.find('_')
+            if -1 == pos:
+                continue
+            options.append(option[0:pos])
+        values = []
+        for option in set(options):
+            type = self.config.get(section, option + '_type')
+            path = self.config.get(section, option + '_path')
+            values.append( ( type, path ) )
+        return values
+
 
     def get_tree(self, parent, child):
         """Retrieve an option for the tree view.  The child may be None."""
@@ -169,6 +194,20 @@ class Options:
         self.__flush()
 
 
+    def set_whitelist_paths(self, values):
+        """Save thee whitelist"""
+        section = "whitelist/paths"
+        if self.config.has_section(section):
+            self.config.remove_section(section)
+        self.config.add_section(section)
+        counter = 0
+        for value in values:
+            self.config.set(section, str(counter) + '_type', value[0])
+            self.config.set(section, str(counter) + '_path', value[1])
+            counter += 1
+        self.__flush()
+
+
     def set_language(self, langid, value):
         """Set the value for a locale (whether to preserve it)"""
         if not self.config.has_section('preserve_languages'):
