@@ -40,7 +40,7 @@ except:
 else:
     HAVE_HASHLIB = True
 
-from Common import _
+from Common import _, _p
 from CleanerML import list_cleanerml_files
 from Options import options
 import GuiBasic
@@ -103,9 +103,11 @@ def cleaner_change_dialog(changes, parent):
     renderer0 = gtk.CellRendererToggle()
     renderer0.set_property('activatable', True)
     renderer0.connect('toggled', toggled, liststore)
-    treeview.append_column(gtk.TreeViewColumn(_('Delete'), renderer0, active = 0))
+    # TRANSLATORS: This is the column label (header) in the tree view for the security dialog
+    treeview.append_column(gtk.TreeViewColumn(_p('column_label', 'Delete'), renderer0, active = 0))
     renderer1 = gtk.CellRendererText()
-    treeview.append_column(gtk.TreeViewColumn(_('Filename'), renderer1, text = 1))
+    # TRANSLATORS: This is the column label (header) in the tree view for the security dialog
+    treeview.append_column(gtk.TreeViewColumn(_p('column_label', 'Filename'), renderer1, text = 1))
 
     # populate tree view
     for change in changes:
