@@ -1,7 +1,7 @@
 # vim: ts=4:sw=4:expandtab
 
 ## BleachBit
-## Copyright (C) 2009 Andrew Ziem
+## Copyright (C) 2010 Andrew Ziem
 ## http://bleachbit.sourceforge.net
 ##
 ## This program is free software: you can redistribute it and/or modify
@@ -17,10 +17,13 @@
 ## You should have received a copy of the GNU General Public License
 ## along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+
+
 """
 Check for updates via the Internet
 """
 
+
 import platform
 import socket
 import sys
@@ -31,16 +34,25 @@ import xml.dom.minidom
 import Common
 
 
+
 def user_agent():
     """Return the user agent string"""
     __platform = platform.system() # Linux or Windows
     __os = platform.uname()[2] # e.g., 2.6.28-12-generic or XP
     if sys.platform == "win32":
-        # Python 2.5.4 shows uname()[2) as Vista on Windows 7
+        # misleading: Python 2.5.4 shows uname()[2] as Vista on Windows 7
         __os = platform.uname()[3][0:3] # 5.1 = Windows XP, 6.0 = Vista, 6.1 = 7
-    if sys.platform == 'linux2':
-        dist = platform.dist()
-        __os = dist[0] + '/' + dist[1] + '-' + dist[2]
+    elif sys.platform == 'linux2':
+        dist = platform.dist() 
+        # example: ('fedora', '11', 'Leonidas')
+        # example: ('', '', '') for Arch Linux
+        if 0 < len(dist[0]):
+            __os = dist[0] + '/' + dist[1] + '-' + dist[2]
+    elif sys.platform[:6] == 'netbsd':
+        __sys = platform.system()
+        mach = platform.machine()
+        rel = platform.release()
+        __os = __sys + '/' + mach+ ' '  + rel
     __locale = ""
     try:
         import locale
@@ -63,7 +75,7 @@ class Update:
 
     def get_update_info_url(self):
         """Return the URL with information about the update.
-        If no update is available, URL may be none."""
+        If no update is available, URL may be None."""
         return self.update_info_url
 
 
@@ -72,12 +84,13 @@ class Update:
         opener = urllib2.build_opener()
         opener.addheaders = [('User-Agent', user_agent())]
         socket.setdefaulttimeout(Common.socket_timeout)
+        handle = opener.open(Common.update_check_url)
+        doc = handle.read()
         try:
-            handle = opener.open(Common.update_check_url)
-            dom = xml.dom.minidom.parse(handle)
+            dom = xml.dom.minidom.parseString(doc)
         except:
-            print _("Error when checking for updates: "), str(sys.exc_info()[1])
-            return False
+            print doc
+            raise
         elements = dom.getElementsByTagName("url")
         if 0 == len(elements):
             self.update_available = False
@@ -87,31 +100,5 @@ class Update:
         dom.unlink()
         return self.update_available
 
-import unittest
-
-class TestUpdate(unittest.TestCase):
-    """Unit tests for module Update"""
 
 
-    def test_Update(self):
-        """Unit tests for class Update"""
-        update = Update()
-        available = update.is_update_available()
-        print "Update available = ", available
-        self.assert_ (type(available) is bool)
-
-        # test failure
-        Common.update_check_url = "http://www.surelydoesnotexist.com/foo"
-        self.assertEqual(update.is_update_available(), False)
-
-
-    def test_user_agent(self):
-        """Unit test for method user_agent()"""
-        agent = user_agent()
-        print "debug: user agent = '%s'" % (agent, )
-        self.assert_ (type(agent) is str)
-
-
-if __name__ == '__main__':
-    unittest.main()
-
