@@ -144,6 +144,7 @@ def delete_registry_key(parent_key, really_delete):
     Return boolean whether found and success.  If really
     delete is False (meaning preview), just check whether
     the key exists."""
+    parent_key = str(parent_key) # Unicode to byte string
     (hive, parent_sub_key) = split_registry_key(parent_key)
     hkey = None
     try:
@@ -154,6 +155,9 @@ def delete_registry_key(parent_key, really_delete):
             return False
     if not really_delete:
         return True
+    if not hkey:
+        # key not found
+        return False
     keys_size = _winreg.QueryInfoKey(hkey)[0]
     child_keys = []
     for i in range(keys_size):
@@ -222,10 +226,16 @@ def enumerate_processes():
     """Return list of module names (e.g., firefox.exe) of running
     processes"""
 
+    r = []
     if platform.win32_ver()[0] == 'XP':
-        return enumerate_processes_win32()
+        r = enumerate_processes_win32()
     else:
-        return enumerate_processes_wmic()
+        r = enumerate_processes_wmic()
+
+    # make unique
+    r = list(set(r))
+    r.sort()
+    return r
 
 
 
